@@ -13,7 +13,6 @@ import matplotlib.pyplot as plt
 import pyomo.environ as pe
 import pyomo.opt as po
 
-import ipopt_wrapper
 
 from ase.build import fcc111
 from ase.data import atomic_numbers, covalent_radii
@@ -33,12 +32,15 @@ class geom2graph:
     
     """
     
-    def __init__(self, surface_type = 'Pt', vasp = None, atoms = None, solver = 'mindtpy', distance_tune = 1.2, H_dist = 2.75):
-        
+    def __init__(self, surface_type = 'Pt', vasp = None, atoms = None, solver = 'glpk', distance_tune = 1.2, H_dist = 2.75, ddec6=None):
+          
         self.surface_type = surface_type
-        self.solver = solver            
+        self.solver = solver
+        
         self.vasp = vasp    
         self.atoms = atoms
+        self.ddec6 = ddec6
+   
         self.distance_tune = distance_tune
         self.H_dist = H_dist
         
@@ -215,7 +217,7 @@ class geom2graph:
                             if j not in self.graph.nodes:
                             
                                 self.graph.add_node(j, element= self.surface_type, valency = 99, edges = 1, unoccupied = 98)
-                            self.graph.add_edge(i,j, weight = 0)
+                            self.graph.add_edge(i,j, weight = 0, bond_index = 0)
     
     def get_gcn(self):
         
@@ -309,7 +311,7 @@ class geom2graph:
         return active_site_nn
     
         
-    def gen_graph(self, h_surface = False, fill_bonds = True):
+    def gen_graph(self, h_surface = False, fill_bonds = True, distances = True, weight = 'bond_index'):
         
         # Create graph from subgraph, giving each node a name by index
         
@@ -330,9 +332,9 @@ class geom2graph:
             for j in self.edge_dict[i]:
                 
                 if {self.graph.nodes[i]['element'], self.graph.nodes[j]['element']} == {'H', self.surface_type}:
-                    self.graph.add_edge(i,j, weight = 0)
+                    self.graph.add_edge(i,j, bond_index = 0)
                 else:
-                    self.graph.add_edge(i,j, weight = 1)
+                    self.graph.add_edge(i,j, bond_index = 1)
 
         for node in self.graph.nodes:    
             self.graph.nodes[node]['valency'] = valency[self.graph.nodes[node]['element']]
@@ -351,7 +353,7 @@ class geom2graph:
         if self.solver_results['model']:
             
             for index in model.edge_weights_ads:
-                self.graph.edges[index]['weight'] = int(model.edge_weights_ads[index].value)
+                self.graph.edges[index]['bond_index'] = int(model.edge_weights_ads[index].value)
                 
             if self.surface_type in [self.graph.nodes[i]['element'] for i in self.graph.nodes]:
                 
@@ -380,15 +382,40 @@ class geom2graph:
                         edges_pt_dict[edge] = edge_sum
                 
                 for index in edges_pt_dict: 
-                    self.graph.edges[index]['weight'] = round(edges_pt_dict[index],3)
-                
-            
+                    self.graph.edges[index]['bond_index'] = round(edges_pt_dict[index],3)
+                    
         else:
             # for index in self.graph.edges:
             #     self.graph.edges[index]['weight'] = 'N/A'
                 
-            self.graph.graph['bonds_solved'] = "Problem with solver"
-
+            self.graph.graph['bonds_solved'] = "Problem with solver"     
+            
+        if distances:
+            
+            for ind1, ind2 in self.graph.edges:
+                self.graph.edges[ind1, ind2]['distance'] = self.min_img_dist(self.positions[ind1], self.positions[ind2])
+        
+        for edge in self.graph.edges:
+            self.graph.edges[edge]['weight'] = self.graph.edges[edge][weight]
+        
+        return self.graph
+    
+    def min_img_dist(self, pos1, pos2):
+        
+        cell = np.array(self.atoms._cellobj)
+        
+        periodics = np.array([-1, 0, 1])
+        distances = np.empty(27)
+        
+        idx = 0
+        
+        for i in periodics:
+            for j in periodics:
+                for k in periodics:
+                    distances[idx] = np.linalg.norm(np.sum(pos1 + np.array([i,j,k]) * cell.T - pos2, axis = 1))
+                    idx +=1
+                    
+        return min(distances)
 
     def fill_bonds(self):
         
@@ -400,13 +427,13 @@ class geom2graph:
         for edge in self.graph.edges:
             
             if 'H' in self.symbols[[edge]]:
-                edges_hs[edge] = self.graph.edges[edge]['weight']
+                edges_hs[edge] = self.graph.edges[edge]['bond_index']
             
             elif self.surface_type in self.symbols[[edge]]:
-                    edges_pts[edge] = self.graph.edges[edge]['weight']
+                    edges_pts[edge] = self.graph.edges[edge]['bond_index']
                     
             else:
-                edges_ads[edge] = self.graph.edges[edge]['weight']
+                edges_ads[edge] = self.graph.edges[edge]['bond_index']
         
         # Sort nodes into surface and adsorbate
         for node in self.graph.nodes:
@@ -419,7 +446,7 @@ class geom2graph:
                 nodes_ads[node] = node_dict[node]['valency']
 
         if not edges_ads and not edges_pts:
-            print('Solving' + str(self.atoms[self.adsorbate_atoms].symbols))
+            print('Solving ' + str(self.atoms[self.adsorbate_atoms].symbols))
             print('No adsorbate/slab edges; trivial solution returned')
             return None, None
         
@@ -539,22 +566,26 @@ if __name__=="__main__":
     
     import pickle as pk
     import pandas as pd
-    pickleFile = open("Examples/ase_to_graph/LDA_ads_systems.pkl", 'rb')
-    LDA = pk.load(pickleFile)
-    df_LDA = pd.DataFrame(LDA).drop(['Graph'], axis=1)
+    from ddec6_graph_gen import gen_graph_ddec6
+    # pickleFile = open("Examples/ase_to_graph/LDA_ads_systems.pkl", 'rb')
+    # LDA = pk.load(pickleFile)
+    # df_LDA = pd.DataFrame(LDA).drop(['Graph'], axis=1)
     
-    dfgeom = df_LDA.dropna()
+    # dfgeom = df_LDA.dropna()
 
-    geomlist = [geom2graph(surface_type = i['Substrate'], atoms = i['Geometry'], solver = 'glpk') for index, i in dfgeom.iterrows()]
+    # geomlist = [geom2graph(surface_type = i['Substrate'], atoms = i['Geometry'], solver = 'glpk') for index, i in dfgeom.iterrows()]
 
-    for count,i in enumerate(geomlist):
-        print(count)
-        i.gen_graph(fill_bonds=True)
+    # for count,i in enumerate(geomlist):
+    #     print(count)
+    #     i.gen_graph(fill_bonds=True)
     
     # vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCARmethane')
     # vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCARpraneetalphahdown')
     # vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCAR_CHCH_holhol')
-    vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCAR_Ir_CH3_hol', surface_type = 'Ir')
+    
+    ddec6 = gen_graph_ddec6('Examples/ddec6')
+    
+    vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCAR_Pt_CHOH_ontop', surface_type = 'Pt', ddec6=ddec6)
     
     # vasp.find_active_site_x_nearest_neighbors(2)
     
@@ -562,7 +593,7 @@ if __name__=="__main__":
     #     vasp.atoms[i].symbol = 'Al'
     # for i in vasp.active_site_nn[1]:
     #     vasp.atoms[i].symbol = 'Au'
-    vasp.add_h_surf_bonds()
+    # vasp.add_h_surf_bonds()
     vasp.gen_graph()
     vasp.get_SMILES_string()
     print(vasp.smiles_string)
