@@ -18,28 +18,28 @@ from sklearn.cluster import KMeans
 
 from itertools import compress
 
+from ase.data.colors import jmol_colors
+from ase.data import chemical_symbols
+
+
 def draw_surf_graph(graph, cutoff = 0.3, 
                     node_label_type = 'element', edge_labels = False, edge_label_type = 'weight'):
    
-    graph = remove_small_edges(graph, cutoff = cutoff)
+    if edge_label_type !='weight' and edge_labels == False:
+        edge_labels=True
+    
+    if cutoff:
+        graph = remove_small_edges(graph, cutoff = cutoff)
 
     plt.figure(figsize=(6,5))
    
     metals = ['Ni', 'Ir','Pd','Pt']
    
-    colors = {'Ni': [52/255, 235/255, 91/255],
-              'Ir': [58/255, 173/255, 194/255],
-              'Pd': [64/255, 127/255, 222/255],
-              'Pt': [177/255, 185/255, 196/255],
-              'C': [127/255, 131/255, 138/255],
-              'H': [200/255, 200/255, 200/255],
-              'O': [200/255, 0, 0],
-              'N': [0.5,0.5,200/255]}    
+    colors = {i:j.reshape(1,-1) for i,j in zip(chemical_symbols, jmol_colors)}  
+    colors['M'] = [0.5, 0.5, 0.5]
 
-    for i in colors.keys():
-        colors[i] = np.array(colors[i]).reshape(1,-1)              
-             
-   
+    # for i in colors.keys():
+    #     colors[i] = np.array(colors[i]).reshape(1,-1)              
 
     element_count = {i: [] for i in colors.keys()}
 
@@ -71,16 +71,21 @@ def draw_surf_graph(graph, cutoff = 0.3,
     for i in element_count.keys():
         if not element_count[i]:
             continue
-        if any(i==j for j in ['Ni', 'Ir', 'Pd','Pt']):
-            nx.draw_networkx_nodes(graph, pos, nodelist=element_count[i],node_size=100, node_color = colors[i])
+        if any(i==j for j in metals):
+            nx.draw_networkx_nodes(graph, pos, nodelist=element_count[i],
+                                   node_size=200, node_color = colors[i],
+                                   edgecolors = (0,0,0), alpha = 0.5)
         else:
-            nx.draw_networkx_nodes(graph, pos, nodelist=element_count[i],node_size=400, node_color = colors[i])
+            nx.draw_networkx_nodes(graph, pos, nodelist=element_count[i],
+                                   node_size=400, node_color = colors[i],
+                                   edgecolors=(0,0,0), alpha = 0.5)
 
        
        
     nx.draw_networkx_edges(graph, pos, alpha = 0.5)
    
     labels = nx.get_node_attributes(graph, node_label_type)
+    
     nx.draw_networkx_labels(graph, pos, labels)
     
     if edge_labels:
@@ -661,4 +666,19 @@ def match_not_pt(x, y,xname, yname):
         returns[i['Substrate']]['X'].append(copy.deepcopy(i[xname]))
         returns[i['Substrate']]['y'].append(copy.deepcopy(y[(y['Adsorbate'] ==ads) & (y['Site'] == site)][yname].to_numpy()[0]))
         
-    return returns
\ No newline at end of file
+    return returns
+
+def min_img_dist(cell, pos1, pos2):
+    periodics = np.array([-1, 0, 1])
+    distances = np.empty(27)
+    
+    idx = 0
+    
+    for i in periodics:
+        for j in periodics:
+            for k in periodics:
+                distances[idx] = np.linalg.norm(np.sum(pos1 + np.array([i,j,k]) * cell.T, axis = 1))
+                idx +=1
+    return min(distances)
+    
+    
\ No newline at end of file
